rulebase.rules.sentence\_segmentation.sentence\_segmenter module
================================================================

.. automodule:: rulebase.rules.sentence_segmentation.sentence_segmenter
    :members:
    :undoc-members:
    :show-inheritance:
